.. testsetup:: *

   import string, operator
   from pwnlib.util.iters import *


:mod:`pwnlib.util.iters` --- Extension of standard module :mod:`itertools`
==========================================================================

.. automodule:: pwnlib.util.iters
   :members:
   :exclude-members:
     chain                                  ,
     combinations                           ,
     combinations_with_replacement          ,
     compress                               ,
     count                                  ,
     cycle                                  ,
     dropwhile                              ,
     filter                                 ,
     filterfalse                            ,
     groupby                                ,
     islice                                 ,
     map                                    ,
     permutations                           ,
     product                                ,
     repeat                                 ,
     starmap                                ,
     takewhile                              ,
     tee                                    ,
     zip                                    ,
     zip_longest

.. function:: chain

   Alias for :func:`itertools.chain`.

.. function:: combinations

   Alias for :func:`itertools.combinations`

.. function:: combinations_with_replacement

   Alias for :func:`itertools.combinations_with_replacement`

.. function:: compress

   Alias for :func:`itertools.compress`

.. function:: count

   Alias for :func:`itertools.count`

.. function:: cycle

   Alias for :func:`itertools.cycle`

.. function:: dropwhile

   Alias for :func:`itertools.dropwhile`

.. function:: groupby

   Alias for :func:`itertools.groupby`

.. function:: filter

   Alias for python3-style :func:`filter`

.. function:: filterfalse

   Alias for :func:`itertools.filterfalse`

.. function:: map

   Alias for python3-style :func:`map`

.. function:: islice

   Alias for :func:`itertools.islice`

.. function:: zip

   Alias for python3-style :func:`zip`

.. function:: zip_longest

   Alias for :func:`itertools.zip_longest`

.. function:: permutations

   Alias for :func:`itertools.permutations`

.. function:: product

   Alias for :func:`itertools.product`

.. function:: repeat

   Alias for :func:`itertools.repeat`

.. function:: starmap

   Alias for :func:`itertools.starmap`

.. function:: takewhile

   Alias for :func:`itertools.takewhile`

.. function:: tee

   Alias for :func:`itertools.tee`

